@@ -93,6 +93,8 @@ extern WandExport MagickBooleanType
   MagickAutoLevelImage(MagickWand *),
   MagickAutoOrientImage(MagickWand *),
   MagickAutoThresholdImage(MagickWand *,const AutoThresholdMethod),
+  MagickBilateralImage(MagickWand *,const double,const double,const double,
+    const double),
   MagickBlackThresholdImage(MagickWand *,const PixelWand *),
   MagickBlueShiftImage(MagickWand *,const double),
   MagickBlurImage(MagickWand *,const double,const double),
@@ -204,7 +206,6 @@ extern WandExport MagickBooleanType
   MagickLocalContrastImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMeanShiftImage(MagickWand *,const size_t,const size_t,const double),
-  MagickMedianConvolveImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
   MagickModeImage(MagickWand *,const double),
   MagickModulateImage(MagickWand *,const double,const double,const double),
